<?php

namespace Drupal\vgwort\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure VG Wort settings for this site.
 *
 * @todo Consider adding validation for publisher_id and domain.
 *
 * @internal
 */
class VgWortSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vgwort_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['vgwort.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('vgwort.settings');

    $form['publisher_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Publisher ID (Karteinummer)'),
      '#default_value' => $config->get('publisher_id'),
      '#description' => $this->t('Your ID provided by VG Wort.'),
    ];

    $form['image_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Counter domain'),
      '#default_value' => $config->get('image_domain'),
      '#description' => $this->t('The counter domain that is provided by VG Wort.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('vgwort.settings')
      ->set('publisher_id', $form_state->getValue('publisher_id'))
      ->set('image_domain', $form_state->getValue('image_domain'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
