<?php

namespace Drupal\vgwort\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'vgwort_counter_id_image' formatter.
 *
 * Default field formatting is removed using the
 * field--vgwort-counter-id.html.twig template.
 *
 * @FieldFormatter(
 *   id = "vgwort_counter_id_image",
 *   label = @Translation("VG Wort counter ID image"),
 *   field_types = {
 *     "vgwort_counter_id",
 *   }
 * )
 *
 * @see vgwort_theme()
 */
class CounterIdImage extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    foreach ($items as $delta => $item) {
      $elements[$delta] = $this->viewValue($item);
    }
    return $elements;
  }

  /**
   * Generate the output appropriate for one field item.
   *
   * @param \Drupal\Core\Field\FieldItemInterface $item
   *   One field item.
   *
   * @return array
   *   Counter ID image generated as a render array.
   */
  protected function viewValue(FieldItemInterface $item) {
    // The VG Wort documentation says to use border="0" but this is no longer
    // supported by HTML5. Should this be omitted?
    // The alt attribute has been added as this is how the HTML appears in VG
    // Wort's user interface.
    // @todo should we use a proper template for more flexibility?
    return [
      '#type' => 'inline_template',
      '#template' => '<img src="\\\\{{ url }}" height="1" width="1" alt=""/>',
      '#context' => ['url' => $item->url],
    ];
  }

}
