<?php

namespace Drupal\Tests\vgwort\Kernel\DataProducer;

use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\graphql\Kernel\GraphQLTestBase;

/**
 * Data producers EntityLinks test class.
 *
 * @group Thunder
 */
class VgWortDataProducerTest extends GraphQLTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'vgwort',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $contentType = NodeType::create([
      'type' => 'article',
      'name' => 'Article',
    ]);
    $contentType->save();
    $this->installConfig('vgwort');
  }

  /**
   * Tests basic data producer functionality.
   */
  public function testDataProducer(): void {
    $configData = [
      'prefix' => 'vgzm',
      'publisher_id' => '12345678',
      'image_domain' => 'example.com',
    ];
    $config = \Drupal::configFactory()->getEditable('vgwort.settings');
    $config->setData($configData)->save();

    $node = Node::create([
      'title' => 'Title',
      'type' => 'article',
    ]);

    $node->save();

    $result = $this->executeDataProducer('vgwort', [
      'entity' => $node,
    ]);

    $this->assertNotNull($result);
    $this->assertEquals($node->vgwort_counter_id->value, $result['counterId']);
    $this->assertEquals($node->vgwort_counter_id->url, $result['url']);
  }

}
